From c458731bdecf080bdc4dcda9bb73c27af88a3d60 Mon Sep 17 00:00:00 2001
From: anonym <anonym@riseup.net>
Date: Sun, 5 Mar 2017 13:10:43 +0100
Subject: [PATCH] Test suite: make sure "Disable network" works for network
 devices plugged post-boot.

---
 features/networking.feature             |  2 ++
 features/step_definitions/networking.rb | 16 ++++++++++++++++
 features/support/helpers/vm_helper.rb   | 18 +++++++++++-------
 3 files changed, 29 insertions(+), 7 deletions(-)
 create mode 100644 features/step_definitions/networking.rb

diff --git a/features/networking.feature b/features/networking.feature
index a5e15b2f7c..ca4ad4d4a0 100644
--- a/features/networking.feature
+++ b/features/networking.feature
@@ -17,6 +17,8 @@ Feature: Networking
     And I disable all networking in the Tails Greeter
     And I log in to a new session
     Then no network interfaces are enabled
+    When I plug a USB network device
+    Then no network interfaces are enabled
 
   #11463
   @fragile
diff --git a/features/step_definitions/networking.rb b/features/step_definitions/networking.rb
new file mode 100644
index 0000000000..96bb12bb0b
--- /dev/null
+++ b/features/step_definitions/networking.rb
@@ -0,0 +1,16 @@
+When /^I plug a USB network device$/ do
+  $vm.execute_successfully('lsusb').stdout
+  STDERR.puts 'X'*60
+  $vm.plug_device(
+    <<-EOF
+      <interface type='network'>
+        <mac address='52:54:11:aa:bb:cc'/>
+        <source network='TailsToasterNet'/>
+        <model type='usb-net'/>
+        <link state='up'/>
+      </interface>
+    EOF
+  )
+  device_id = '0525:a4a2'
+  try_for(10) { $vm.execute_successfully('lsusb').stdout[device_id] }
+end
diff --git a/features/support/helpers/vm_helper.rb b/features/support/helpers/vm_helper.rb
index bbfdfa6b9b..e766e319c5 100644
--- a/features/support/helpers/vm_helper.rb
+++ b/features/support/helpers/vm_helper.rb
@@ -223,6 +223,16 @@ class VM
     return ret
   end
 
+  def plug_device(xml)
+    if is_running?
+      @domain.attach_device(xml.to_s)
+    else
+      domain_xml = REXML::Document.new(@domain.xml_desc)
+      domain_xml.elements['domain/devices'].add_element(xml)
+      update(domain_xml.to_s)
+    end
+  end
+
   def plug_drive(name, type)
     if disk_plugged?(name)
       raise "disk '#{name}' already plugged"
@@ -252,13 +262,7 @@ class VM
     xml.elements['disk/target'].attributes['bus'] = type
     xml.elements['disk/target'].attributes['removable'] = removable_usb if removable_usb
 
-    if is_running?
-      @domain.attach_device(xml.to_s)
-    else
-      domain_xml = REXML::Document.new(@domain.xml_desc)
-      domain_xml.elements['domain/devices'].add_element(xml)
-      update(domain_xml.to_s)
-    end
+    plug_device(xml)
   end
 
   def disk_xml_desc(name)
-- 
2.11.0

